package net.wanji.opt.vo;

import com.alibaba.excel.annotation.ExcelIgnore;
import com.alibaba.excel.annotation.ExcelProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/2/9 8:38
 */
@Data
@NoArgsConstructor
@ApiModel(value = "TableQueryVO", description = "表格分时段查询")
public class TableQueryVO {

    @ApiModelProperty(value = "实时数据")
    private List<RealTimeDataElement> realTimeData;

    @ApiModelProperty(value = "周期数据")
    private List<CycleDataElement> cycleData;

    @NoArgsConstructor
    @Data
    public static class RealTimeDataElement {
        @ApiModelProperty(value = "时间 格式 yyyy-MM-dd HH:mm:ss")
        @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
        @ExcelProperty("时间")
        private Date time;

        @ApiModelProperty(value = "方向：1北；2东北；3东；4东南；5南；6西南；7西；8西北")
        @ExcelIgnore
        private Integer dir;
        @ExcelProperty("方向")
        private String dirName;

        @ApiModelProperty(value = "车道，从左车道开始编号11、12、13...")
        @ExcelProperty("车道号")
        private String laneSort;

        @ApiModelProperty(value = "车道编号")
        @ExcelIgnore
        private String laneId;

        @ApiModelProperty(value = "排队长度")
        @ExcelProperty("排队长度")
        private Integer queueLength;

        @ApiModelProperty(value = "头车位置")
        @ExcelProperty("头车位置")
        private Integer firstCarPosition;

        @ApiModelProperty(value = "末车位置")
        @ExcelProperty("末车位置")
        private Integer endCarPosition;

        @ApiModelProperty(value = "排队车辆数")
        @ExcelProperty("排队车辆数")
        private int queueNums;

        @ApiModelProperty(value = "车道内车辆数")
        @ExcelProperty("车道内车辆数")
        private int carNums;

        @ApiModelProperty(value = "空间密度车辆负荷比")
        @ExcelIgnore
        private double vehicleNumsRatio;

        @ApiModelProperty(value = "空间密度（长度占比）")
        @ExcelProperty("车辆分布情况")
        private double vehicleLengthRatio;

        @ApiModelProperty(value = "平均速度")
        @ExcelProperty("平均速度")
        private double speed;

        @ApiModelProperty(value = "头车速度")
        @ExcelProperty("头车速度")
        private double headSpeed;

        @ApiModelProperty(value = "末车速度")
        @ExcelProperty("末车速度")
        private double mailSpeed;

        @ApiModelProperty(value = "队首距离(米)")
        @ExcelProperty("队首距离")
        private double teamHeadDistance;

        @ApiModelProperty(value = "队尾距离(米)")
        @ExcelProperty("队尾距离")
        private double teamTailDistance;

        @ApiModelProperty(value = "空间长度占比>车道内空间占有率")
        @ExcelProperty("空间占有率%")
        private double stdSpaceHeadway;

        @ApiModelProperty(value = "溢出区车辆数")
        @ExcelProperty("溢出区车辆数")
        private int overflowNums;

    }

    @NoArgsConstructor
    @Data
    public static class CycleDataElement {
        @ApiModelProperty(value = "时间 格式 yyyy-MM-dd HH:mm:ss")
        @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
        @ExcelProperty("时间")
        private Date time;

        @ApiModelProperty(value = "方向：1北；2东北；3东；4东南；5南；6西南；7西；8西北")
        @ExcelIgnore
        private Integer dir;

        @ExcelProperty("方向名称")
        private String dirName;

        @ApiModelProperty(value = "车道转向：1左转；2直行；3右转；4掉头；5直左；6直右；7左直右；8左右；9左转掉头；10直行掉头；11右转掉头；12左直掉头；13直右掉头；14左直右掉头；15左右掉头',\n")
        @ExcelIgnore
        private Integer turn;

        @ApiModelProperty(value = "车道，从左车道开始编号11、12、13...")
        @ExcelProperty("车道号")
        private String laneSort;

        @ApiModelProperty(value = "流量")
//        @ExcelIgnore
        @ExcelProperty("机动车流量")
        private Integer flow;

        @ApiModelProperty(value = "最大排队")
        @ExcelProperty("最大排队")
        private double queueLength;

        @ApiModelProperty(value = "平均延误")
        @ExcelProperty("平均延误")
        private Integer delayTime ;

        @ApiModelProperty(value = "路口效率指数")
        @ExcelProperty("路口效率指数")
        private Double efficiencyIndex ;

        @ApiModelProperty(value = "效率评价等级")
        @ExcelProperty("效率评价等级")
        private Double efficiencyEvaluateLevel ;

        @ApiModelProperty(value = "平均停车次数")
        @ExcelProperty("平均停车次数")
        private double stopTimes;

        @ApiModelProperty(value = "平均车头时距")
        @ExcelProperty("平均车头时距")
        private double vehheadTime;

        @ApiModelProperty(value = "饱和度")
        @ExcelProperty("饱和度")
        private Double saturation;

        @ApiModelProperty(value = "拥堵指数")
        @ExcelProperty("拥堵指数")
        private Double congestionIndex;

        @ApiModelProperty(value = "溢出指数")
        @ExcelProperty("溢出指数")
        private Double overflowIndex= 0.0d;

        @ApiModelProperty(value = "失衡指数")
        @ExcelProperty("失衡指数")
        private Double imbalanceIndex;

        @ApiModelProperty(value = "平均车头间距")
        @ExcelProperty("平均车身间距")
        private Double vehheadDist;

        @ApiModelProperty(value = "时间占有率")
        @ExcelProperty("平均时间占有率%")
        private double timeOccupancy;

        @ApiModelProperty(value = "空间占有率")
        // 空间长度占比 todo字段名称展示先不改了
        @ExcelProperty("平均空间占有率%")
        private double vehicleNumsRatioMean;
        @ExcelProperty("85位速度")
        private double v85;
        @ApiModelProperty(value = "速度")
        @ExcelProperty("平均速度")
        private double speed;
        @ExcelProperty("大车流量")
        private Integer trafficFlowA;
        @ExcelProperty("中车流量")
        private Integer trafficFlowB;
        @ExcelProperty("小车流量")
        private Integer trafficFlowC;
        @ApiModelProperty(value = "非机动车流量")
        @ExcelProperty("非机动车流量")
        private int nonMotorFlow;
        @ApiModelProperty(value = "行人流量")
        @ExcelProperty("行人流量")
        private int pedFlow;

        @ApiModelProperty(value = "路口服务水平")
        @ExcelProperty("路口服务水平")
        private int serviceLevel;

        @ApiModelProperty(value = "拥堵次数")
        @ExcelProperty("拥堵次数")
        private int congestionTimes;

        @ApiModelProperty(value = "溢出次数")
        @ExcelProperty("溢出次数")
        private double overflowTimes;

        @ApiModelProperty(value = "失衡次数")
        @ExcelProperty("失衡次数")
        private int imbalanceTimes;

        @ApiModelProperty(value = "空放次数")
        @ExcelProperty("空放次数")
        private int freeFlowTimes;

        @ApiModelProperty(value = "溢流率")
        @ExcelProperty("溢流率")
        private double overflowRate;

        @ApiModelProperty(value = "冲突点")
        @ExcelProperty("冲突点")
        private int conflictPoint;

        @ApiModelProperty(value = "路口安全系数")
        @ExcelProperty("路口安全系数")
        private double safetyCoefficient;

        @ApiModelProperty(value = "安全评价等级")
        @ExcelProperty("安全评价等级")
        private double safetyEvaluateLevel;

        @ApiModelProperty(value = "交通事件数")
        @ExcelProperty("交通事件数")
        private int trafficEventNum;

        @ApiModelProperty(value = "交通事故数")
        @ExcelProperty("交通事故数")
        private int trafficAccidentNum;

        @ApiModelProperty(value = "不停车通过率")
        @ExcelProperty("不停车通过率")
        private double noStopPassRate;

        @ApiModelProperty(value = "一次停车通过率")
        @ExcelProperty("一次停车通过率")
        private double oneStopPassRate;

        @ApiModelProperty(value = "二次停车通过率")
        @ExcelProperty("二次停车通过率")
        private double twoStopPassRate;

        @ApiModelProperty(value = "路口未清空率")
        @ExcelProperty("路口未清空率")
        private double crossNoClearRate;

        @ApiModelProperty(value = "平均排队长度")
        @ExcelProperty("平均排队长度")
        private double avgQueueLength;

        @ApiModelProperty(value = "绿灯有效利用率")
        @ExcelProperty("绿灯有效利用率")
        private double greenLightEfficiency ;

        @ApiModelProperty(value = "行人平均通过时间")
        @ExcelProperty("行人平均通过时间")
        private double pedAvgPassTime;

        @ApiModelProperty(value = "行人闯红灯率")
        @ExcelProperty("行人闯红灯率")
        private double pedCrossRedLightRate;

        @ApiModelProperty(value = "车辆总和")
        @ExcelProperty("车辆总和")
        private int allVehiceleFlow;
        @ApiModelProperty(value = "总流量")
        @ExcelProperty("总流量")
        private int allFlow;

        @ApiModelProperty(value = "车道编号")
        @ExcelIgnore
        private String laneId;
    }
}
